@@ -27,12 +27,12 @@ import numpy as np
 import sys
 import os
 from pathlib2 import Path
-import vtk
+from vtkplotlib._get_vtk import vtk, QVTKRenderWindowInteractor
 
 from PyQt5.QtWidgets import QApplication, QWidget, QVBoxLayout
-from vtk.qt.QVTKRenderWindowInteractor import QVTKRenderWindowInteractor
 from vtkplotlib.figures.BaseFigure import BaseFigure, VTKRenderer
 from vtkplotlib import nuts_and_bolts
+from vtkplotlib._vtk_errors import handler
 
 
 class QtFigure(BaseFigure, QWidget):
@@ -191,13 +191,18 @@ class QtFigure(BaseFigure, QWidget):
 #        print("layout")
         self.vl = QVBoxLayout()
 #        print("vtkwidget")
-        self.vtkWidget = QVTKRenderWindowInteractor()
+        self.vtkWidget = QVTKRenderWindowInteractor(self)
 #        print("addWidget")
         self.vl.addWidget(self.vtkWidget)
 #        print("renwon")
         self.renWin
         iren = self.iren
 
+        # try to prevent error pop-up windows
+        handler.attach(self.vtkWidget)
+        handler.attach(self.iren)
+        handler.attach(self.renWin)
+
 
         self.data_holder = []
 #        print("basefig init")
@@ -242,9 +247,34 @@ class QtFigure(BaseFigure, QWidget):
         pass
 
 
+def test():
+    import vtkplotlib as vpl
+
+    self = QtFigure("a qt widget figure")
+
+    assert self is vpl.gcf()
+
+    direction = np.array([1, 0, 0])
+    vpl.quiver(np.array([0, 0, 0]), direction)
+    vpl.view(camera_direction=direction)
+    vpl.reset_camera()
+
+#    vpl.show()
+    self.show()
+#    self.__init__()
+#    self.show()
+#    self.vtkWidget.show()
+#    self.update()
+#    self.show(False)
+#    self.update()
+#    self.vtkWidget.show()
+#    self.qapp.exec_()
+
+
+    globals().update(locals())
 
 
 
 if __name__ == "__main__":
-    pass
+    test()
 
